@@ -1,4 +1,4 @@
-mod instructions;
+pub mod instructions;
 pub mod state;
 
 use {anchor_lang::prelude::*, instructions::*};
